==> blackfin-vdsp-1.0b.zip: blackfin-vdsp/bf533/sys_config.h <==
/*
 *  TOPPERS/JSP Kernel
 *      Toyohashi Open Platform for Embedded Real-Time Systems/
 *      Just Standard Profile Kernel
 * 
 *  Copyright (C) 2000-2003 by Embedded and Real-Time Systems Laboratory
 *                              Toyohashi Univ. of Technology, JAPAN
 *
 *  TOPPERS/JSP for Blackfin
 *
 *  Copyright (C) 2004 by Suikan
 *  Copyright (C) 2004 by Ujinosuke
 *
 *  L쌠҂́Cȉ (1)`(4) ̏CFree Software Foundation 
 *  ɂČ\Ă GNU General Public License  Version 2 ɋL
 *  qĂ𖞂ꍇɌC{\tgEFAi{\tgEFA
 *  ς̂܂ށDȉjgpEEρEĔzziȉC
 *  pƌĂԁj邱Ƃ𖳏ŋD
 *  (1) {\tgEFA\[XR[ȟ`ŗpꍇɂ́CL̒
 *      \C̗pщL̖ۏ؋K肪Ĉ܂܂̌`Ń\[
 *      XR[hɊ܂܂Ă邱ƁD
 *  (2) {\tgEFACCu`ȂǁC̃\tgEFAJɎg
 *      pł`ōĔzzꍇɂ́CĔzzɔhLgip
 *      ҃}jAȂǁjɁCL̒쌠\C̗pщL
 *      ̖ۏ؋Kfڂ邱ƁD
 *  (3) {\tgEFAC@ɑgݍނȂǁC̃\tgEFAJɎg
 *      płȂ`ōĔzzꍇɂ́Ĉꂩ̏𖞂
 *      ƁD
 *    (a) ĔzzɔhLgip҃}jAȂǁjɁCL̒
 *        쌠\C̗pщL̖ۏ؋Kfڂ邱ƁD
 *    (b) Ĕzž`ԂCʂɒ߂@ɂāCTOPPERSvWFNg
 *        񍐂邱ƁD
 *  (4) {\tgEFA̗pɂ蒼ړI܂͊ԐړIɐ邢Ȃ鑹
 *      QCL쌠҂TOPPERSvWFNgƐӂ邱ƁD
 * 
 *  {\tgEFÁCۏ؂Œ񋟂Ă̂łDL쌠҂
 *  TOPPERSvWFNǵC{\tgEFAɊւāC̓Kp\
 *  ܂߂āCȂۏ؂sȂD܂C{\tgEFA̗pɂ蒼
 *  ړI܂͊ԐړIɐȂ鑹QɊւĂC̐ӔC𕉂ȂD
 * 
 *  
 */


#ifndef _SYS_CONFIG_H_
#define _SYS_CONFIG_H_


/*
 *  J[l̓ʖ̃l[
 */
#include <sys_rename.h>

 
/*
 *	^[QbgVXeˑW[iEZKIT-BF533pj
 *
 *  ̃CN[ht@ĆCt_config.h ݂̂CN[hD
 *  ̃t@C璼ڃCN[hĂ͂ȂȂD
 *
 * ǂ̂悤ȃNbN͂ɂΉł悤AȉCSEL, SSEL, MSEL̒l
 * ƃNbN͎g(Hz)w肷BPLL̃vOsys_config.c
 * sys_initialize()֐ōsB
 */
 
#define CSELVAL 1
#define SSELVAL 5
#define MSELVAL 22
#define CLKIN 27000000
 

/*
 *  ^[QbgVXẽn[hEFA̒`
 * 
 *  DEVICE_INTERRUPT_COUNTSIC_IMASK̃rbg
 *  ^B
 *  ADSP-BF533̃rbg24Ȃ̂ŁAl24łB
 */

#define DEVICE_INTERRUPT_COUNT 24
 
/*
 *  NbZ[W̃^[QbgVXe
 */
#define	TARGET_NAME	"ADSP-BF533"


/*
 *  TICp^C}[̎
 */
#define PLLCLOCK (CLKIN*MSELVAL)
#define SYSCLOCK  (PLLCLOCK / SSELVAL)
#define CORECLOCK (PLLCLOCK / CSELVAL)

/*
 * TICp^C}[̐ݒ
 * USE_TIC_COREdefineƁACORE^C}[gp
 * RgAEgƁAGP_TIMER_2gp
 *
 * CORE^C}[wakeupM𐶐Ȃ߁AfBXpb`
 * idle߂gCORE^C}[Cxg҂ƂłȂB
 * ̂߁AUSE_TIC_COREgƃfBXpb`idle߂
 * g킸Ɋ荞ݔ|[Oő҂B͏d͂
 * _ŕsłB
 *
 */

//#define USE_TIC_CORE

/*
 *  TIC̊݃nh̃xN^ԍ
 */
#ifdef USE_TIC_CORE
#define INHNO_TIMER	INHNO_CORE_TIMER
#else
#define INHNO_TIMER	INHNO_GP_TIMER2
#endif


/*
 *  VA|[g̒`
 *  pidc/simple_sio/uart.cŎgB
 */
#define TNUM_PORT	0	/* T|[gVA|[g̐ */
#define TNUM_SIOP	0	/* T|[gVA|[g̐ */

/*
 *  VA|[gԍɊւ`
 */
#define	LOGTASK_PORTID	0	/* VXeOɗpVA|[gԍ */





/*
 *  VA|[g̃{[[gɊւ`
 *
 *  UART̃{[[gWFl[^ɐݒ肷ׂlD
 *  pidc/simple_sio/uart.cŎgB
 */

#define DLH_VAL	SYSCLOCK/16/115200/256		/* 115200bpsiʁj*/
#define DLL_VAL	SYSCLOCK/16/115200%256		/* 115200bpsiʁj*/

/*
 *  VA|[g̃AhX
 *  pidc/simple_sio/uart.cŎgB
 *
 */
#define UART_0 0xFFC00400	// UART THR̃AhXB

/*
 *  ԑ҂̂߂̒`
 *  sil_dly_nsěĂяoI[o[wbhƃ[v{fB[TCN
 *  nSŕ\B֐cpu_support.asmɒ`ĂB
 *  SIL_DLY_TIM124TCNB32nS( 750MHz ), 40nS( 600MHz )
 *  SIL_DLY_TIM212TCNB16nS( 750MHz ), 20nS( 600MHz )
 */


#define	SIL_DLY_TIM1	(24*1000000000/CORECLOCK)
#define	SIL_DLY_TIM2	(12*1000000000/CORECLOCK)


/*
 *  荞݃xNgԍ
 *
 *  ̒`̓RtBO[Vt@CDEF_INḦƂĎg
 *  SIC_ISRɂrbgԍłB
 *
 */
#define INHNO_PLL			0
#define INHNO_DMA_ERROR		1
#define INHNO_PPI_ERROR		2
#define INHNO_SPORT0_ERROR	3
#define INHNO_SPORT2_ERROR	4
#define INHNO_SPI_ERROR		5
#define INHNO_UART_ERROR	6
#define INHNO_RTC			7
#define INHNO_PPI			8
#define INHNO_SPORT0_RX		9
#define INHNO_SPORT0_TX		10
#define INHNO_SPORT1_RX		11
#define INHNO_SPORT1_TX		12
#define INHNO_SPI			13
#define INHNO_UART_RX		14
#define INHNO_UART_TX		15
#define INHNO_GP_TIMER0		16
#define INHNO_GP_TIMER1		17
#define INHNO_GP_TIMER2		18
#define INHNO_PFA			19
#define INHNO_PFB			20
#define INHNO_MEMORY_DMA0	21
#define INHNO_MEMORY_DMA1	22
#define INHNO_WDG			23

// SIC_ISRɂȂȊ荞
#define INHNO_HW_ERROR 		24
#define INHNO_GP_TIMER 		25
#define INHNO_RAISE 		26

/*
 *  ÕxN^ԍ
 *
 *  ̒`̓RtBO[Vt@CDEF_EXC̈ƂĎg
 *  SEQSTATEXCAUSElł
 */
/*
#define EXCNO_EXCPT_0		0
#define EXCNO_EXCPT_1		1
#define EXCNO_EXCPT_2		2
#define EXCNO_EXCPT_3		3
#define EXCNO_EXCPT_4		4
#define EXCNO_EXCPT_5		5
#define EXCNO_EXCPT_6		6
#define EXCNO_EXCPT_7		7
#define EXCNO_EXCPT_8		8
#define EXCNO_EXCPT_9		9
#define EXCNO_EXCPT_10		10
#define EXCNO_EXCPT_11		11
#define EXCNO_EXCPT_12		12
#define EXCNO_EXCPT_13		13
#define EXCNO_EXCPT_14		14
// 15TOPPERS/JSPŎgpĂ̂Ō

#define EXCNO_SINGLE_STEP	16
#define EXCNO_TRACE			17

#define EXCNO_UNDEFINED_INSTRUCTION		0x21
#define	EXCNO_ILLEGAL_COMBINATION		0x22

#define EXCNO_DATA_CPLB_PROTECTION		0x23
#define EXCNO_DATA_MISSALIGNED_ACCESS	0x24
#define EXCNO_UNRECOVERED_EVENT			0x25
#define EXCNO_DATA_CPLB_MISS			0x26
#define EXCNO_DATA_CPLB_MULTIPLE_HIT	0x27
#define EXCNO_WATCH_POINT				0x28

#define EXCNO_INST_MISSALIGNED_ACCESS	0x2a
#define EXCNO_INST_CPLB_PROTECTION		0x2b
#define EXCNO_INST_CPLB_MISS			0x2c
#define EXCNO_INST_CPLB_MULTIPLE_HIT	0x2d
#define EXCNO_ILLEGAL_USE				0x2e
*/
/*
 *  SIC_ISR̊荞݂̃xN^ԍ
 *
 *  ̒`ena_int, dis_inẗƂĎgB
 */

#define INTNO_PLL			0
#define INTNO_DMA_ERROR		1
#define INTNO_PPI_ERROR		2
#define INTNO_SPORT0_ERROR	3
#define INTNO_SPORT2_ERROR	4
#define INTNO_SPI_ERROR		5
#define INTNO_UART_ERROR	6
#define INTNO_RTC			7
#define INTNO_PPI			8
#define INTNO_SPORT0_RX		9
#define INTNO_SPORT0_TX		10
#define INTNO_SPORT1_RX		11
#define INTNO_SPORT1_TX		12
#define INTNO_SPI			13
#define INTNO_UART_RX		14
#define INTNO_UART_TX		15
#define INTNO_GP_TIMER0		16
#define INTNO_GP_TIMER1		17
#define INTNO_GP_TIMER2		18
#define INTNO_PFA			19
#define INTNO_PFB			20
#define INTNO_MEMORY_DMA0	21
#define INTNO_MEMORY_DMA1	22
#define INTNO_WDG			23













#ifndef _MACRO_ONLY

/*
* SIC_IARx͂āACxgʂƂɊ蓖ĂĂ銄荞
* ̃rbg}bvBSIC_IARx̃tB[hl͗D揇-7Ȃ̂
* ̕␳B
*/
void make_priority_mask( void );

/*
 *  ^[QbgVXeˑ̏
 */
extern void	sys_initialize(void);

/*
 *  ^[QbgVXȅI
 *
 *  VXeI鎞ɎgDROMj^^GDB STUBďoŎD
 */
extern void	sys_exit(void);

/*
 *  ^[QbgVXe̕o
 *
 *  VXe̒჌x̕o̓[`DROMj^^GDB STUBďoŎ
 *  D
 */
extern void	sys_putc(char c);

/*
* SIC_IARx͂āACxgʂƂɊ蓖ĂĂ銄荞
* ̃rbg}bvBSIC_IARx̃tB[hl͗D揇-7Ȃ̂
* ̕␳B
*/
void make_priority_mask( void );

/*
 * 荞݂̋A֎~
 *
 */
typedef unsigned int INTNO; 
extern ER ena_int( INTNO intno );
extern ER dis_int( INTNO intno );

/*
 * 荞݃}XN̑
 *
 *
 */
typedef unsigned int IMS;
extern ER chg_ims( IMS ims );
extern ER get_ims( IMS * p_ims );


#endif /* _MACRO_ONLY */
#endif /* _SYS_CONFIG_H_ */

==> blackfin-vdsp_1.2.1.zip: blackfin-vdsp/bf533/sys_config.h <==
/*
 *  TOPPERS/JSP Kernel
 *      Toyohashi Open Platform for Embedded Real-Time Systems/
 *      Just Standard Profile Kernel
 * 
 *  Copyright (C) 2000-2003 by Embedded and Real-Time Systems Laboratory
 *                              Toyohashi Univ. of Technology, JAPAN
 *
 *  TOPPERS/JSP for Blackfin
 *
 *  Copyright (C) 2004 by Suikan
 *  Copyright (C) 2004 by Ujinosuke
 *
 *  L쌠҂́Cȉ (1)`(4) ̏CFree Software Foundation 
 *  ɂČ\Ă GNU General Public License  Version 2 ɋL
 *  qĂ𖞂ꍇɌC{\tgEFAi{\tgEFA
 *  ς̂܂ށDȉjgpEEρEĔzziȉC
 *  pƌĂԁj邱Ƃ𖳏ŋD
 *  (1) {\tgEFA\[XR[ȟ`ŗpꍇɂ́CL̒
 *      \C̗pщL̖ۏ؋K肪Ĉ܂܂̌`Ń\[
 *      XR[hɊ܂܂Ă邱ƁD
 *  (2) {\tgEFACCu`ȂǁC̃\tgEFAJɎg
 *      pł`ōĔzzꍇɂ́CĔzzɔhLgip
 *      ҃}jAȂǁjɁCL̒쌠\C̗pщL
 *      ̖ۏ؋Kfڂ邱ƁD
 *  (3) {\tgEFAC@ɑgݍނȂǁC̃\tgEFAJɎg
 *      płȂ`ōĔzzꍇɂ́Ĉꂩ̏𖞂
 *      ƁD
 *    (a) ĔzzɔhLgip҃}jAȂǁjɁCL̒
 *        쌠\C̗pщL̖ۏ؋Kfڂ邱ƁD
 *    (b) Ĕzž`ԂCʂɒ߂@ɂāCTOPPERSvWFNg
 *        񍐂邱ƁD
 *  (4) {\tgEFA̗pɂ蒼ړI܂͊ԐړIɐ邢Ȃ鑹
 *      QCL쌠҂TOPPERSvWFNgƐӂ邱ƁD
 * 
 *  {\tgEFÁCۏ؂Œ񋟂Ă̂łDL쌠҂
 *  TOPPERSvWFNǵC{\tgEFAɊւāC̓Kp\
 *  ܂߂āCȂۏ؂sȂD܂C{\tgEFA̗pɂ蒼
 *  ړI܂͊ԐړIɐȂ鑹QɊւĂC̐ӔC𕉂ȂD
 * 
 *  
 */


#ifndef _SYS_CONFIG_H_
#define _SYS_CONFIG_H_


/*
 *  J[l̓ʖ̃l[
 */
#include <sys_rename.h>

/*
* {[hݒt@C̓ǂݍ
*/
#include <board_config.h>
 
/*
 *	^[QbgVXeˑW[iEZKIT-BF533pj
 *
 *  ̃CN[ht@ĆCt_config.h ݂̂CN[hD
 *  ̃t@C璼ڃCN[hĂ͂ȂȂD
*/

/*
 *  ^[QbgVXẽn[hEFA̒`
 * 
 *  DEVICE_INTERRUPT_COUNTSIC_IMASK̃rbg
 *  ^B
 *  ADSP-BF533̃rbg24Ȃ̂ŁAl24łB
 */

#define DEVICE_INTERRUPT_COUNT 24
 


/*
 *  TICp^C}[̎
 */
#define PLLCLOCK (CLKIN*MSELVAL)
#define SYSCLOCK  (PLLCLOCK / SSELVAL)
#define CORECLOCK (PLLCLOCK / CSELVAL)



/*
 *  TIC̊݃nh̃xN^ԍ
 */
#ifdef USE_TIC_CORE
#define INHNO_TIMER	INHNO_CORE_TIMER
#else
#define INHNO_TIMER	INHNO_GP_TIMER2
#endif


/*
 *  VA|[g̒`
 *  pidc/simple_sio/uart.cŎgB
 */
#define TNUM_PORT	0	/* T|[gVA|[g̐ */
#define TNUM_SIOP	0	/* T|[gVA|[g̐ */

/*
 *  VA|[gԍɊւ`
 */
#define	LOGTASK_PORTID	0	/* VXeOɗpVA|[gԍ */


/*
 *  VA|[g̃{[[gɊւ`
 *
 *  UART̃{[[gWFl[^ɐݒ肷ׂlD
 *  pidc/simple_sio/uart.cŎgB
 */

#define DLH_VAL	SYSCLOCK/16/115200/256		/* 115200bpsiʁj*/
#define DLL_VAL	SYSCLOCK/16/115200%256		/* 115200bpsiʁj*/

/*
 *  VA|[g̃AhX
 *  pidc/simple_sio/uart.cŎgB
 *
 */
#define UART_0 0xFFC00400	// UART THR̃AhXB

/*
 *  ԑ҂̂߂̒`
 *  sil_dly_nsěĂяoI[o[wbhƃ[v{fB[TCN
 *  nSŕ\B֐cpu_support.asmɒ`ĂB
 *  SIL_DLY_TIM124TCNB32nS( 750MHz ), 40nS( 600MHz )
 *  SIL_DLY_TIM212TCNB16nS( 750MHz ), 20nS( 600MHz )
 */


#define	SIL_DLY_TIM1	(24*1000000000/CORECLOCK)
#define	SIL_DLY_TIM2	(12*1000000000/CORECLOCK)


/*
 *  荞݃xNgԍ
 *
 *  ̒`̓RtBO[Vt@CDEF_INḦƂĎg
 *  SIC_ISRɂrbgԍłB
 *
 */
#define INHNO_PLL			0
#define INHNO_DMA_ERROR		1
#define INHNO_PPI_ERROR		2
#define INHNO_SPORT0_ERROR	3
#define INHNO_SPORT2_ERROR	4
#define INHNO_SPI_ERROR		5
#define INHNO_UART_ERROR	6
#define INHNO_RTC			7
#define INHNO_PPI			8
#define INHNO_SPORT0_RX		9
#define INHNO_SPORT0_TX		10
#define INHNO_SPORT1_RX		11
#define INHNO_SPORT1_TX		12
#define INHNO_SPI			13
#define INHNO_UART_RX		14
#define INHNO_UART_TX		15
#define INHNO_GP_TIMER0		16
#define INHNO_GP_TIMER1		17
#define INHNO_GP_TIMER2		18
#define INHNO_PFA			19
#define INHNO_PFB			20
#define INHNO_MEMORY_DMA0	21
#define INHNO_MEMORY_DMA1	22
#define INHNO_WDG			23

// SIC_ISRɂȂȊ荞
#define INHNO_HW_ERROR 		24
#define INHNO_GP_TIMER 		25
#define INHNO_RAISE 		26


/*
 *  SIC_ISR̊荞݂̃xN^ԍ
 *
 *  ̒`ena_int, dis_inẗƂĎgB
 */

#define INTNO_PLL			0
#define INTNO_DMA_ERROR		1
#define INTNO_PPI_ERROR		2
#define INTNO_SPORT0_ERROR	3
#define INTNO_SPORT2_ERROR	4
#define INTNO_SPI_ERROR		5
#define INTNO_UART_ERROR	6
#define INTNO_RTC			7
#define INTNO_PPI			8
#define INTNO_SPORT0_RX		9
#define INTNO_SPORT0_TX		10
#define INTNO_SPORT1_RX		11
#define INTNO_SPORT1_TX		12
#define INTNO_SPI			13
#define INTNO_UART_RX		14
#define INTNO_UART_TX		15
#define INTNO_GP_TIMER0		16
#define INTNO_GP_TIMER1		17
#define INTNO_GP_TIMER2		18
#define INTNO_PFA			19
#define INTNO_PFB			20
#define INTNO_MEMORY_DMA0	21
#define INTNO_MEMORY_DMA1	22
#define INTNO_WDG			23



#ifndef _MACRO_ONLY

/*
* SIC_IARx͂āACxgʂƂɊ蓖ĂĂ銄荞
* ̃rbg}bvBSIC_IARx̃tB[hl͗D揇-7Ȃ̂
* ̕␳B
*/
void make_priority_mask( void );

/*
 *  ^[QbgVXeˑ̏
 */
extern void	sys_initialize(void);

/*
 *  ^[QbgVXȅI
 *
 *  VXeI鎞ɎgDROMj^^GDB STUBďoŎD
 */
extern void	sys_exit(void);

/*
 *  ^[QbgVXe̕o
 *
 *  VXe̒჌x̕o̓[`DROMj^^GDB STUBďoŎ
 *  D
 */
extern void	sys_putc(char c);

/*
* SIC_IARx͂āACxgʂƂɊ蓖ĂĂ銄荞
* ̃rbg}bvBSIC_IARx̃tB[hl͗D揇-7Ȃ̂
* ̕␳B
*/
void make_priority_mask( void );

/*
 * 荞݂̋A֎~
 *
 */
typedef unsigned int INTNO; 
extern ER ena_int( INTNO intno );
extern ER dis_int( INTNO intno );

/*
 * 荞݃}XN̑
 *
 *
 */
typedef unsigned int IMS;
extern ER chg_ims( IMS ims );
extern ER get_ims( IMS * p_ims );


#endif /* _MACRO_ONLY */
#endif /* _SYS_CONFIG_H_ */
